@@ -1,7 +1,9 @@
 # Names to expose to the outside
 
 from .defines import *
-from .pixelformats import * # overwrite some missing def's from register() calls
+from .pixels import *
 from .constants import * # including things that would otherwise involve math in an enum declaration
 from .autohelpers import *
-from .helpers import *
\ No newline at end of file
+from .helpers import *
+
+SDL_BlitSurface = SDL_UpperBlit
\ No newline at end of file
