@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 
-import os.path, textwrap, StringIO, json
+import os.path, textwrap, StringIO, json, sys
 
 from lxml.etree import XSLT, XML, parse, tostring
 
+DEBUG=False
+
 def get_dox(dox_file):
     """Use XSLT to parse certain documentation out of doxygen xml."""
     dox = parse(dox_file)
@@ -18,22 +20,31 @@ def reformat(result):
     funcdocs = {}
     for funcdef in result.xpath(".//function"):
         if not funcdef.text: continue
+        if DEBUG:
+            print funcdef.text
         sio = StringIO.StringIO()
-        last_line = ':'
+        last_line = ''
         for line in funcdef.text.splitlines():
             line = line.lstrip()
             if not line:
                 continue
-            if not line.startswith(':para') and not line.startswith(':para'):
-                sio.write("\n")
-            sio.write('\n'.join(textwrap.wrap(line)))
-            sio.write("\n")
+            if not (last_line.startswith(':') and line.startswith(':')):
+                if not (last_line.startswith('*  ') and line.startswith('*  ')):
+                    sio.write("\n")
+            if line.startswith('*'): # code examples
+                sio.write(' ' + line[1:])
+            else:
+                subsequent_indent = '' if not line.startswith(':') else '    '
+                sio.write('\n'.join(textwrap.wrap(line,
+                                                  subsequent_indent=subsequent_indent)))
+            sio.write('\n')
+            last_line = line
         funcdocs[funcdef.attrib['name']] = sio.getvalue()
     return funcdocs
 
 all_funcdocs = {}
 
-base_path = "../SDL2-2.0.3/include/xml/"
+base_path = sys.argv[1]
 for a, b, files in os.walk(base_path):
     for filename in files:
         if not filename.endswith('.xml'): continue
@@ -43,4 +54,5 @@ for a, b, files in os.walk(base_path):
 
 with open('dox.json', 'w+') as dox_out:
     json.dump(all_funcdocs, dox_out, indent=2)
-
+    # print all_funcdocs['SDL_CreateWindow']
+    # print all_funcdocs['SDL_WarpMouseInWindow']
